==> mgug4120a_1.10.0.tar.gz: mgug4120a/man/mgug4120aPMID2PROBE.Rd <==
\name{mgug4120aPMID2PROBE}
\alias{mgug4120aPMID2PROBE}
\title{Map between PubMed Identifiers and Manufacturer Identifiers}
\description{
  mgug4120aPMID2PROBE is an R environment that provides mappings between
  PubMed ids and manufacturer ids.
}
\details{
  Each PubMed id is mapped to a named vector of manufacturer ids. The
  name represents the PubMed id and the vector contains all manufacturer
  ids that are represented by that PubMed id. The length of the vector
  may be one or longer, depending on how many manufacturer ids are
  mapped to a given PubMed id.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed id. The pubmed function of
  annotate can also be used for the same purpose
  
  Mappings were based on data provided by:
  
  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue Oct  4 22:33:58 2005 
  
  Package built Tue Oct  4 22:44:57 2005
}

\examples{
    # Convert the environment to a list
    xx <- as.list(mgug4120aPMID2PROBE)
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && require(annotate)){
            # Gets article information as XML files for a PubMed id
            xmls <- pubmed(names(xx)[1], disp = "data")
            # Views article information using a browser
            pubmed(names(xx)[1], disp = "browser")
        }
    }
}

\keyword{datasets}

==> mgug4120a_1.12.0.tar.gz: mgug4120a/man/mgug4120aPMID2PROBE.Rd <==
\name{mgug4120aPMID2PROBE}
\alias{mgug4120aPMID2PROBE}
\title{Map between PubMed Identifiers and Manufacturer Identifiers}
\description{
  mgug4120aPMID2PROBE is an R environment that provides mappings between
  PubMed ids and manufacturer ids.
}
\details{
  Each PubMed id is mapped to a named vector of manufacturer ids. The
  name represents the PubMed id and the vector contains all manufacturer
  ids that are represented by that PubMed id. The length of the vector
  may be one or longer, depending on how many manufacturer ids are
  mapped to a given PubMed id.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed id. The pubmed function of
  annotate can also be used for the same purpose
  
  Mappings were based on data provided by:
  
  Entrez Gene:\url{ftp://ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Sun Mar 26 02:04:36 2006 
  
  Package built Sun Mar 26 02:20:24 2006
}

\examples{
    # Convert the environment to a list
    xx <- as.list(mgug4120aPMID2PROBE)
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && require(annotate)){
            # Gets article information as XML files for a PubMed id
            xmls <- pubmed(names(xx)[1], disp = "data")
            # Views article information using a browser
            pubmed(names(xx)[1], disp = "browser")
        }
    }
}

\keyword{datasets}
